@@ -19,27 +19,40 @@ from suite_py.commands import check
 from suite_py.commands import ip
 from suite_py.commands import generator
 from suite_py.lib.handler import prompt_utils
+from suite_py.lib.handler import git_handler as git
 from suite_py.lib.config import Config
 from suite_py.__version__ import __version__
 
 
 config = Config()
 
-# TODO: fixme -> write something more smart in locating the current project
-def confirm_cwd():
-    project_path = os.getcwd()
-    project = os.path.basename(project_path)
-    if not prompt_utils.ask_confirm(f"Vuoi continuare sul progetto {project}?"):
+
+def get_cwd():
+    path = os.getcwd()
+    if not is_project(path):
+        print("Spostati in una cartella di un progetto prima o usa l'opzione --project")
         sys.exit(-1)
-    return project_path
+    if config.load()["user"].get(
+        "skip_confirmation", False
+    ) or prompt_utils.ask_confirm(
+        f"Vuoi continuare sul progetto {os.path.basename(path)}?"
+    ):
+        return path
+    sys.exit(-1)
+
+
+def is_project(path):
+    return git.is_repo(path) and os.path.basename(path) in os.listdir(
+        config.load()["user"]["projects_home"]
+    )
 
 
 @click.group()
 @click.option(
     "--project",
     type=click.Path(exists=True),
-    default=confirm_cwd,
-    help="Nome del progetto su cui eseguire il comando (default directory corrente)",
+    default=get_cwd,
+    help="Path del progetto su cui eseguire il comando (default directory corrente)",
 )
 @click.option(
     "--timeout",
@@ -50,9 +63,8 @@ def confirm_cwd():
 def main(ctx, project, timeout):
     Package("suite_py").upgrade()
     print(f"v{__version__}")
-    project_name = os.path.basename(project)
     ctx.ensure_object(dict)
-    ctx.obj["project"] = project_name
+    ctx.obj["project"] = os.path.basename(project)
     ctx.obj["captainhook_timeout"] = timeout  # Might be also None
     os.chdir(os.path.join(config.load()["user"]["projects_home"], ctx.obj["project"]))
 
@@ -144,9 +156,7 @@ def cli_check(ctx):
     check.entrypoint(ctx.obj["captainhook_timeout"])
 
 
-@main.command(
-    "ip", help="Ottieni gli indirizzi IP degli hosts dove il task è running",
-)
+@main.command("ip", help="Ottieni gli indirizzi IP degli hosts dove il task è running")
 @click.argument("environment", type=click.Choice(("staging", "production")))
 @click.pass_context
 def cli_ip(ctx, environment):
