@@ -11,8 +11,8 @@ youtrack = YoutrackHandler()
 logger = Logger()
 
 
-def entrypoint():
-    branch_name = git.current_branch_name()
+def entrypoint(project):
+    branch_name = git.current_branch_name(project)
 
     logger.info("Spengo il qa se esite...")
     qainit_shutdown(branch_name)
