@@ -39,16 +39,10 @@ def entrypoint(project, timeout, env, action):
 
 
 def handle_request(request):
-    if request.status_code == 401:
-        logger.error("Impossibie contattare captainhook, stai usando la VPN?")
-        sys.exit(-1)
-    if request.status_code == 500:
-        logger.error(
-            "Si è verificato un errore su captainhook. Chiedi ai devops di verificare (X_X)"
-        )
-        sys.exit(-1)
     if request.status_code != 200:
-        logger.error("Qualcosa è andato storto durante la richiesta.")
+        logger.error(
+            "Qualcosa è andato storto durante la richiesta. Richiedi supporto ai devops su slack."
+        )
         sys.exit(-1)
 
     return True
