@@ -18,6 +18,20 @@ def _get_path(repo):
     return os.path.join(config.load()["user"]["projects_home"], repo)
 
 
+def is_repo(directory):
+    try:
+        subprocess.run(
+            ["git", "status"],
+            cwd=directory,
+            check=True,
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
+        )
+        return True
+    except CalledProcessError:
+        return False
+
+
 def clone(repo):
     subprocess.run(
         ["git", "clone", f"git@github.com:primait/{repo}.git"],
@@ -81,9 +95,7 @@ def commit(repo, commit_message="", dummy=False):
 
 def add(repo):
     try:
-        subprocess.run(
-            ["git", "add", "."], cwd=_get_path(repo), check=True,
-        )
+        subprocess.run(["git", "add", "."], cwd=_get_path(repo), check=True)
     except (CalledProcessError) as e:
         logger.error(f"Errore eseguendo il comando: {e}")
         sys.exit(-1)
